:root {
  /* SunPy Theme Colors */
  --sst-accent-color-bright: #ff5000;
  --sst-accent-color-muted: #fc9468;
  --sst-dark-color: #404040;
  --sst-darker-color: #333333;
  --sst-darkest-color: #222222;
  --sst-light-color: rgb(206, 206, 206);
  --sst-lighter-color: rgb(231, 231, 231);
  --sst-lightest-color: rgb(251, 251, 251);
}

/* Override the sunpy sphinx theme link colors to pst defaults */
html[data-theme="light"] {
  --pst-color-link-hover: #8045e5;
  --pst-color-link: #0a7d91;
}

html[data-theme="dark"] {
  --pst-color-link-hover: #9c5ffd;
  --pst-color-link: #3fb1c5;
}

.concertina-toggle.dropdown-item:hover,
.navbar-nav .concertina-toggle:hover,
.bd-header .dropdown-item:hover,
.bd-header .concertina-toggle:hover {
  /* Override the header link color back to sunpy */
  color: var(--sst-accent-color-muted);
  background-color: transparent;
  text-decoration: underline;
}
